FzStringSet

Struct FzStringSet 

pub struct FzStringSet<T, BH = DefaultBuildHasher> { /* private fields */ }
A set optimized for fast read access with string values.

A frozen collection differs from the traditional Rust collections, such as HashMap and HashSet types in three key ways. First, creating a frozen collection performs an analysis over the input data to determine the best implementation strategy. Depending on the situation, this analysis is performed at build time or runtime, and it can take a relatively long time when a collection is very large. Second, once created, the keys in frozen collections are immutable. And third, querying a frozen collection is typically considerably faster, which is the whole point.

This type requires that the keys implement the Eq and Hash traits. This can frequently be achieved by using #[derive(PartialEq, Eq, Hash)]. If you implement these yourself, it is important that the following property holds:

k1 == k2 -> hash(k1) == hash(k2)

In other words, if two keys are equal, their hashes must be equal. Violating this property is a logic error.

It is also a logic error for a key to be modified in such a way that the key’s hash, as determined by the Hash trait, or its equality, as determined by the Eq trait, changes while it is in the collection. This is normally only possible through core::cell::Cell, core::cell::RefCell, global state, I/O, or unsafe code.

The behavior resulting from either logic error can include panics, incorrect results, memory leaks, and non-termination.

Implementations

Source

impl FzStringSet<Box<str>, DefaultBuildHasher>

pub fn new(entries: Vec<impl AsRef<str>>) -> Self

Creates a new frozen set. If the input contains duplicate value, the latter one in the input is used and all former ones are discarded.

Source

impl<BH> FzStringSet<Box<str>, BH>

pub fn with_hasher(entries: Vec<impl AsRef<str>>, bh: BH) -> Self
where BH: BuildHasher + Clone + Send + Sync + 'static,

Creates a new frozen set which uses the given hash builder to hash values. If the input contains duplicate value, the latter one in the input is used and all former ones are discarded.

Source

impl<'a> FzStringSet<&'a str, DefaultBuildHasher>

pub fn new_for_str(entries: Vec<&'a str>) -> Self

Creates a new frozen set. If the input contains duplicate value, the latter one in the input is used and all former ones are discarded.

Source

impl<'a, BH> FzStringSet<&'a str, BH>

pub fn with_hasher_for_str(entries: Vec<&'a str>, bh: BH) -> Self
where BH: BuildHasher + Clone + Send + Sync + 'static,

Creates a new frozen set which uses the given hash builder to hash values. If the input contains duplicate value, the latter one in the input is used and all former ones are discarded.

Source

impl<T, BH> FzStringSet<T, BH>

pub fn get(&self, value: impl AsRef<str>) -> Option<&T>
where BH: BuildHasher, str: Equivalent<T>,

Gets a reference to a value in the set.

pub fn contains(&self, value: impl AsRef<str>) -> bool
where BH: BuildHasher, str: Equivalent<T>,

Checks whether a particular value is present in the set.

pub fn len(&self) -> usize

Returns the number of elements in the collection.

pub fn is_empty(&self) -> bool

Returns true if the collection contains no elements.

pub fn iter(&self) -> Iter<'_, T>

An iterator visiting all entries in arbitrary order.