pub struct InlineHashMapNoCollisions<K, V, const SZ: usize, const NHS: usize, CM = SmallCollection, H = BridgeHasher> { /* private fields */ }Expand description
A general-purpose map implemented using a hash table.
This type requires that the keys
implement the Eq and Hash traits. This can frequently be achieved by
using #[derive(PartialEq, Eq, Hash)]. If you implement these yourself,
it is important that the following property holds:
k1 == k2 -> hash(k1) == hash(k2)In other words, if two keys are equal, their hashes must be equal. Violating this property is a logic error.
It is also a logic error for a key to be modified in such a way that the key’s
hash, as determined by the Hash trait, or its equality, as determined by
the Eq trait, changes while it is in the collection. This is normally only
possible through core::cell::Cell, core::cell::RefCell, global state, I/O,
or unsafe code.
The behavior resulting from either logic error can include panics, incorrect results, memory leaks, and non-termination.
Type Parameters
K: The key type.V: The value type.CM: The magnitude of the map, one ofSmallCollection,MediumCollection, orLargeCollection.SZ: The number of entries in the map.NHS: The number of hash table slots.H: The hasher to generate hash codes.
Implementations
Sourceimpl<K, V, const SZ: usize, const NHS: usize, CM, H> InlineHashMapNoCollisions<K, V, SZ, NHS, CM, H>where
CM: CollectionMagnitude,
impl<K, V, const SZ: usize, const NHS: usize, CM, H> InlineHashMapNoCollisions<K, V, SZ, NHS, CM, H>where
CM: CollectionMagnitude,
Sourcepub const fn new_raw(
table: InlineHashTableNoCollisions<(K, V), SZ, NHS, CM>,
hasher: H,
) -> Self
pub const fn new_raw( table: InlineHashTableNoCollisions<(K, V), SZ, NHS, CM>, hasher: H, ) -> Self
Creates a frozen map.
Sourcepub fn get<Q>(&self, key: &Q) -> Option<&V>
pub fn get<Q>(&self, key: &Q) -> Option<&V>
Returns a reference to the value corresponding to the key.
The key may be any borrowed form of the map’s key type.
Sourcepub fn get_mut<Q>(&mut self, key: &Q) -> Option<&mut V>
pub fn get_mut<Q>(&mut self, key: &Q) -> Option<&mut V>
Returns a mutable reference to the value corresponding to the key.
The key may be any borrowed form of the map’s key type.
Sourcepub fn get_key_value<Q>(&self, key: &Q) -> Option<(&K, &V)>
pub fn get_key_value<Q>(&self, key: &Q) -> Option<(&K, &V)>
Returns the key-value pair corresponding to the supplied key.
This is potentially useful:
-
for key types where non-identical keys can be considered equal;
-
for getting the &K stored key value from a borrowed &Q lookup key; or
-
for getting a reference to a key with the same lifetime as the collection.
-
The supplied key may be any borrowed form of the map’s key type, but Hash and Eq on the borrowed form must match those for the key type.
Sourcepub fn contains_key<Q>(&self, key: &Q) -> bool
pub fn contains_key<Q>(&self, key: &Q) -> bool
Returns true if the map contains a value for the specified key.
The key may be any borrowed form of the map’s key type.
Sourcepub fn get_disjoint_mut<Q, const N: usize>(
&mut self,
keys: [&Q; N],
) -> [Option<&mut V>; N]
pub fn get_disjoint_mut<Q, const N: usize>( &mut self, keys: [&Q; N], ) -> [Option<&mut V>; N]
Gets multiple mutable values from the map.
Panics
Panics if the same key is specified multiple times.
Sourcepub unsafe fn get_disjoint_unchecked_mut<Q, const N: usize>(
&mut self,
keys: [&Q; N],
) -> [Option<&mut V>; N]
pub unsafe fn get_disjoint_unchecked_mut<Q, const N: usize>( &mut self, keys: [&Q; N], ) -> [Option<&mut V>; N]
Gets multiple mutable values from the map.
Safety
Calling this method with overlapping keys is undefined behavior even if the resulting references are not used.
Sourcepub fn iter_mut(&mut self) -> IterMut<'_, K, V> ⓘ
pub fn iter_mut(&mut self) -> IterMut<'_, K, V> ⓘ
An iterator producing mutable references to all entries in arbitrary order.
Sourcepub fn into_keys(self) -> IntoKeys<K, V> ⓘ
pub fn into_keys(self) -> IntoKeys<K, V> ⓘ
A consuming iterator visiting all keys in arbitrary order.
Sourcepub fn values_mut(&mut self) -> ValuesMut<'_, K, V> ⓘ
pub fn values_mut(&mut self) -> ValuesMut<'_, K, V> ⓘ
An iterator visiting all values mutably in arbitrary order.
Sourcepub fn into_values(self) -> IntoValues<K, V> ⓘ
pub fn into_values(self) -> IntoValues<K, V> ⓘ
A consuming iterator visiting all values in arbitrary order.