InlineScanMap

Struct InlineScanMap 

pub struct InlineScanMap<K, V, const SZ: usize> { /* private fields */ }
A general-purpose map implemented using linear scanning.

This type is an implementation detail of the `frozen_collections` crate. This API is therefore not stable and may change at any time. Please do not use this type directly, and instead use the public API provided by the `frozen_collections` crate.
A frozen collection differs from the traditional Rust collections, such as [`HashMap`](std::collections::HashMap) and [`HashSet`](std::collections::HashSet) types in three key ways. First, creating a frozen collection performs an analysis over the input data to determine the best implementation strategy. Depending on the situation, this analysis is performed at build time or runtime, and it can take a relatively long time when a collection is very large. Second, once created, the keys in frozen collections are immutable. And third, querying a frozen collection is typically considerably faster, which is the whole point.

Type Parameters

  • K: The key type.
  • V: The value type.
  • SZ: The number of entries in the map.

Implementations

Source

impl<K, V, const SZ: usize> InlineScanMap<K, V, SZ>

pub fn new(entries: Vec<(K, V)>) -> Self
where K: Eq,

Creates a frozen map.

Panics

Panics if the number of entries in the array differs from the size of the map as specified by the SZ generic argument.

pub const fn new_raw(dedupped_entries: [(K, V); SZ]) -> Self

Creates a frozen map.

Expectations

Callers must ensure:

  • Entries are deduplicated.
pub fn get<Q>(&self, key: &Q) -> Option<&V>
where Q: ?Sized + Equivalent<K>,

Returns a reference to the value corresponding to the key.

The key may be any borrowed form of the map’s key type.

pub fn get_mut<Q>(&mut self, key: &Q) -> Option<&mut V>
where Q: ?Sized + Equivalent<K>,

Returns a mutable reference to the value corresponding to the key.

The key may be any borrowed form of the map’s key type.

pub fn get_key_value<Q>(&self, key: &Q) -> Option<(&K, &V)>
where Q: ?Sized + Equivalent<K>,

Returns the key-value pair corresponding to the supplied key.

This is potentially useful:

  • for key types where non-identical keys can be considered equal;

  • for getting the &K stored key value from a borrowed &Q lookup key; or

  • for getting a reference to a key with the same lifetime as the collection.

  • The supplied key may be any borrowed form of the map’s key type, but Hash and Eq on the borrowed form must match those for the key type.

pub fn contains_key<Q>(&self, key: &Q) -> bool
where Q: ?Sized + Equivalent<K>,

Returns true if the map contains a value for the specified key.

The key may be any borrowed form of the map’s key type.

pub fn get_disjoint_mut<Q, const N: usize>( &mut self, keys: [&Q; N], ) -> [Option<&mut V>; N]
where Q: ?Sized + Eq + Equivalent<K>,

Gets multiple mutable values from the map.

Panics

Panics if the same key is specified multiple times.

pub unsafe fn get_disjoint_unchecked_mut<Q, const N: usize>( &mut self, keys: [&Q; N], ) -> [Option<&mut V>; N]
where Q: ?Sized + Equivalent<K>,

Gets multiple mutable values from the map.

Safety

Calling this method with overlapping keys is undefined behavior even if the resulting references are not used.

pub fn iter(&self) -> Iter<'_, K, V>

An iterator visiting all entries in arbitrary order.

pub fn iter_mut(&mut self) -> IterMut<'_, K, V>

An iterator producing mutable references to all entries in arbitrary order.

pub fn keys(&self) -> Keys<'_, K, V>

An iterator visiting all keys in arbitrary order.

pub fn into_keys(self) -> IntoKeys<K, V>

A consuming iterator visiting all keys in arbitrary order.

pub fn values(&self) -> Values<'_, K, V>

An iterator visiting all values in arbitrary order.

pub fn values_mut(&mut self) -> ValuesMut<'_, K, V>

An iterator visiting all values mutably in arbitrary order.

pub fn into_values(self) -> IntoValues<K, V>

A consuming iterator visiting all values in arbitrary order.

pub const fn len(&self) -> usize

Returns the number of elements in the collection.

pub const fn is_empty(&self) -> bool

Returns true if the collection contains no elements.