InlineHashSet

Struct InlineHashSet 

pub struct InlineHashSet<T, const SZ: usize, const NHS: usize, CM = SmallCollection, H = BridgeHasher> { /* private fields */ }
A general-purpose set implemented using a hash table.

This type is an implementation detail of the `frozen_collections` crate. This API is therefore not stable and may change at any time. Please do not use this type directly, and instead use the public API provided by the `frozen_collections` crate.
A frozen collection differs from the traditional Rust collections, such as [`HashMap`](std::collections::HashMap) and [`HashSet`](std::collections::HashSet) types in three key ways. First, creating a frozen collection performs an analysis over the input data to determine the best implementation strategy. Depending on the situation, this analysis is performed at build time or runtime, and it can take a relatively long time when a collection is very large. Second, once created, the keys in frozen collections are immutable. And third, querying a frozen collection is typically considerably faster, which is the whole point.

This type requires that the keys implement the Eq and Hash traits. This can frequently be achieved by using #[derive(PartialEq, Eq, Hash)]. If you implement these yourself, it is important that the following property holds:

k1 == k2 -> hash(k1) == hash(k2)

In other words, if two keys are equal, their hashes must be equal. Violating this property is a logic error.

It is also a logic error for a key to be modified in such a way that the key’s hash, as determined by the Hash trait, or its equality, as determined by the Eq trait, changes while it is in the collection. This is normally only possible through core::cell::Cell, core::cell::RefCell, global state, I/O, or unsafe code.

The behavior resulting from either logic error can include panics, incorrect results, memory leaks, and non-termination.

Type Parameters

Implementations

Source

impl<T, const SZ: usize, const NHS: usize, CM, H> InlineHashSet<T, SZ, NHS, CM, H>

pub const fn new(map: InlineHashMap<T, (), SZ, NHS, CM, H>) -> Self

Creates a frozen set.

pub fn get<Q>(&self, value: &Q) -> Option<&T>
where Q: ?Sized + Equivalent<T>, H: Hasher<Q>,

Gets a reference to a value in the set.

pub fn contains<Q>(&self, value: &Q) -> bool
where Q: ?Sized + Equivalent<T>, H: Hasher<Q>,

Checks whether a particular value is present in the set.

pub fn iter(&self) -> Iter<'_, T>

An iterator visiting all entries in arbitrary order.

pub const fn len(&self) -> usize

Returns the number of elements in the collection.

pub const fn is_empty(&self) -> bool

Returns true if the collection contains no elements.