pub struct InlineHashSetNoCollisions<T, const SZ: usize, const NHS: usize, CM = SmallCollection, H = BridgeHasher> { /* private fields */ }Expand description
A general-purpose set implemented using a hash table which doesn’t tolerate hash collisions.
This type requires that the keys
implement the Eq and Hash traits. This can frequently be achieved by
using #[derive(PartialEq, Eq, Hash)]. If you implement these yourself,
it is important that the following property holds:
k1 == k2 -> hash(k1) == hash(k2)In other words, if two keys are equal, their hashes must be equal. Violating this property is a logic error.
It is also a logic error for a key to be modified in such a way that the key’s
hash, as determined by the Hash trait, or its equality, as determined by
the Eq trait, changes while it is in the collection. This is normally only
possible through core::cell::Cell, core::cell::RefCell, global state, I/O,
or unsafe code.
The behavior resulting from either logic error can include panics, incorrect results, memory leaks, and non-termination.
Type Parameters
T: The value type.CM: The magnitude of the set, one ofSmallCollection,MediumCollection, orLargeCollection.SZ: The number of entries in the set.NHS: The number of hash table slots.H: The hasher to generate hash codes.
Implementations
Sourceimpl<T, const SZ: usize, const NHS: usize, CM, H> InlineHashSetNoCollisions<T, SZ, NHS, CM, H>where
CM: CollectionMagnitude,
impl<T, const SZ: usize, const NHS: usize, CM, H> InlineHashSetNoCollisions<T, SZ, NHS, CM, H>where
CM: CollectionMagnitude,
Sourcepub const fn new(map: InlineHashMapNoCollisions<T, (), SZ, NHS, CM, H>) -> Self
pub const fn new(map: InlineHashMapNoCollisions<T, (), SZ, NHS, CM, H>) -> Self
Creates a frozen set.