Implementation crate for the frozen collections.
This crate is an implementation detail of the `frozen_collections` crate.
This crate's API is therefore not stable and may change at any time. Please do not
use this crate directly and instead use the public API provided by the
`frozen_collections` crate.
Modules
- emit
- Implementation logic for build script emitter features.
- fz_maps
- Wrappers around other map types allowing runtime selection of implementation types based on input.
- fz_sets
- Wrappers around other set types allowing runtime selection of implementation types based on input.
- hash_
tables - Foundational hash table design.
- hashers
- Hasher implementations for various situations.
- inline_
maps - Specialized static-friendly read-only map types.
- inline_
sets - Specialized static-friendly read-only set types.
- macros
- Implementation logic for frozen collection macros.
- maps
- Specialized read-only map types.
- sets
- Specialized read-only set types.
- traits
- Traits to support frozen collections.
Type Aliases
- Default
Build Hasher - The default hash builder used by the frozen collections.