pub struct LengthHasher;Expand description
Returns the value’s length as the hash.
This type is an implementation detail of the `frozen_collections` crate.
This API is therefore not stable and may change at any time. Please do not
use this type directly, and instead use the public API provided by the
`frozen_collections` crate.