pub struct InlineScanMap<K, V, const SZ: usize> { /* private fields */ }Expand description
A general-purpose map implemented using linear scanning.
Type Parameters
K: The key type.V: The value type.SZ: The number of entries in the map.
Implementations
Sourceimpl<K, V, const SZ: usize> InlineScanMap<K, V, SZ>
impl<K, V, const SZ: usize> InlineScanMap<K, V, SZ>
Sourcepub fn new(entries: Vec<(K, V)>) -> Selfwhere
K: Eq,
pub fn new(entries: Vec<(K, V)>) -> Selfwhere
K: Eq,
Creates a frozen map.
Panics
Panics if the number of entries in the array differs from the size of the map as specified by the SZ generic argument.
Sourcepub fn get<Q>(&self, key: &Q) -> Option<&V>where
Q: ?Sized + Equivalent<K>,
pub fn get<Q>(&self, key: &Q) -> Option<&V>where
Q: ?Sized + Equivalent<K>,
Returns a reference to the value corresponding to the key.
The key may be any borrowed form of the map’s key type.
Sourcepub fn get_mut<Q>(&mut self, key: &Q) -> Option<&mut V>where
Q: ?Sized + Equivalent<K>,
pub fn get_mut<Q>(&mut self, key: &Q) -> Option<&mut V>where
Q: ?Sized + Equivalent<K>,
Returns a mutable reference to the value corresponding to the key.
The key may be any borrowed form of the map’s key type.
Sourcepub fn get_key_value<Q>(&self, key: &Q) -> Option<(&K, &V)>where
Q: ?Sized + Equivalent<K>,
pub fn get_key_value<Q>(&self, key: &Q) -> Option<(&K, &V)>where
Q: ?Sized + Equivalent<K>,
Returns the key-value pair corresponding to the supplied key.
This is potentially useful:
-
for key types where non-identical keys can be considered equal;
-
for getting the &K stored key value from a borrowed &Q lookup key; or
-
for getting a reference to a key with the same lifetime as the collection.
-
The supplied key may be any borrowed form of the map’s key type, but Hash and Eq on the borrowed form must match those for the key type.
Sourcepub fn contains_key<Q>(&self, key: &Q) -> boolwhere
Q: ?Sized + Equivalent<K>,
pub fn contains_key<Q>(&self, key: &Q) -> boolwhere
Q: ?Sized + Equivalent<K>,
Returns true if the map contains a value for the specified key.
The key may be any borrowed form of the map’s key type.
Sourcepub fn get_disjoint_mut<Q, const N: usize>(
&mut self,
keys: [&Q; N],
) -> [Option<&mut V>; N]
pub fn get_disjoint_mut<Q, const N: usize>( &mut self, keys: [&Q; N], ) -> [Option<&mut V>; N]
Gets multiple mutable values from the map.
Panics
Panics if the same key is specified multiple times.
Sourcepub unsafe fn get_disjoint_unchecked_mut<Q, const N: usize>(
&mut self,
keys: [&Q; N],
) -> [Option<&mut V>; N]where
Q: ?Sized + Equivalent<K>,
pub unsafe fn get_disjoint_unchecked_mut<Q, const N: usize>(
&mut self,
keys: [&Q; N],
) -> [Option<&mut V>; N]where
Q: ?Sized + Equivalent<K>,
Gets multiple mutable values from the map.
Safety
Calling this method with overlapping keys is undefined behavior even if the resulting references are not used.
Sourcepub fn iter_mut(&mut self) -> IterMut<'_, K, V> ⓘ
pub fn iter_mut(&mut self) -> IterMut<'_, K, V> ⓘ
An iterator producing mutable references to all entries in arbitrary order.
Sourcepub fn into_keys(self) -> IntoKeys<K, V> ⓘ
pub fn into_keys(self) -> IntoKeys<K, V> ⓘ
A consuming iterator visiting all keys in arbitrary order.
Sourcepub fn values_mut(&mut self) -> ValuesMut<'_, K, V> ⓘ
pub fn values_mut(&mut self) -> ValuesMut<'_, K, V> ⓘ
An iterator visiting all values mutably in arbitrary order.
Sourcepub fn into_values(self) -> IntoValues<K, V> ⓘ
pub fn into_values(self) -> IntoValues<K, V> ⓘ
A consuming iterator visiting all values in arbitrary order.