pub struct InlineScanSet<T, const SZ: usize> { /* private fields */ }Expand description
A general-purpose set implemented using linear scanning.
This type is an implementation detail of the `frozen_collections` crate.
This API is therefore not stable and may change at any time. Please do not
use this type directly, and instead use the public API provided by the
`frozen_collections` crate.
A frozen collection differs from the traditional Rust collections, such as
[`HashMap`](std::collections::HashMap) and [`HashSet`](std::collections::HashSet) types in three
key ways. First, creating a frozen collection performs an analysis over the input data to
determine the best implementation strategy. Depending on the situation, this analysis is
performed at build time or runtime, and it can take a relatively long time when a collection is
very large. Second, once created, the keys in frozen collections are immutable. And third,
querying a frozen collection is typically considerably faster, which is the whole point.
Type Parameters
T: The value type.SZ: The number of entries in the set.
Implementations
Sourceimpl<T, const SZ: usize> InlineScanSet<T, SZ>
impl<T, const SZ: usize> InlineScanSet<T, SZ>
Sourcepub const fn new(map: InlineScanMap<T, (), SZ>) -> Self
pub const fn new(map: InlineScanMap<T, (), SZ>) -> Self
Creates a frozen set.
Sourcepub fn get<Q>(&self, value: &Q) -> Option<&T>where
Q: ?Sized + Equivalent<T>,
pub fn get<Q>(&self, value: &Q) -> Option<&T>where
Q: ?Sized + Equivalent<T>,
Gets a reference to a value in the set.