pub struct InlineSparseScalarLookupSet<T, const SZ: usize, const LTSZ: usize, CM = SmallCollection> { /* private fields */ }Expand description
A set whose values are scalars.
This type is an implementation detail of the `frozen_collections` crate.
This API is therefore not stable and may change at any time. Please do not
use this type directly, and instead use the public API provided by the
`frozen_collections` crate.
A frozen collection differs from the traditional Rust collections, such as
[`HashMap`](std::collections::HashMap) and [`HashSet`](std::collections::HashSet) types in three
key ways. First, creating a frozen collection performs an analysis over the input data to
determine the best implementation strategy. Depending on the situation, this analysis is
performed at build time or runtime, and it can take a relatively long time when a collection is
very large. Second, once created, the keys in frozen collections are immutable. And third,
querying a frozen collection is typically considerably faster, which is the whole point.
Type Parameters
T: The value type.CM: The magnitude of the set, one ofSmallCollection,MediumCollection, orLargeCollection.SZ: The number of entries in the set.LTSZ: The number of entries in the lookup table.
Implementations
Sourceimpl<T, const SZ: usize, const LTSZ: usize, CM> InlineSparseScalarLookupSet<T, SZ, LTSZ, CM>where
CM: CollectionMagnitude,
impl<T, const SZ: usize, const LTSZ: usize, CM> InlineSparseScalarLookupSet<T, SZ, LTSZ, CM>where
CM: CollectionMagnitude,
Sourcepub const fn new(map: InlineSparseScalarLookupMap<T, (), SZ, LTSZ, CM>) -> Self
pub const fn new(map: InlineSparseScalarLookupMap<T, (), SZ, LTSZ, CM>) -> Self
Creates a frozen set.
Sourcepub fn get<Q>(&self, value: &Q) -> Option<&T>where
Q: Comparable<T> + Scalar,
pub fn get<Q>(&self, value: &Q) -> Option<&T>where
Q: Comparable<T> + Scalar,
Gets a reference to a value in the set.